[geodir,meshdir]=fc_vfemp1.default_directories(2);

dim=2;d=2;
N=60;
af=@(x,y) 0.1+y.^2;
gD=@(x,y) 20*y;
b=0.01;
geofile=[geodir,filesep,'disk5holes.geo'];

fprintf('------------------------------------------------------\n'); 
fprintf('      2D stationary heat and flow velocity BVPs\n');
fprintf('         on GMSH mesh from %s.geo\n\n',geofile);
fprintf(' 1) 2D velocity potential BVP, (unknow phi)\n')
fprintf('               - Delta phi = 0\n')
fprintf('    and boundary conditions :\n');
fprintf('      * Dirichlet on [20,21]\n');
fprintf('          phi = -20 on [21], 20 on [20]\n');
fprintf('      * Neumann on [1,22,23]\n');
fprintf('          du/dn = 0 on [1,22,23]\n');
fprintf('    (Velocity V = grad phi ) \n');
fprintf(' 2) 2D stationary heat with potential flow BVP, (unknow u)\n')
fprintf('               - div(a grad u) + <V,grad u> + b u = f\n')
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [21,22,23]\n');
fprintf('       u = gD on [21], 0 on [22] and 0 on [23]  \n');
fprintf('   * Neumann on [1,10,20]\n');
fprintf('       du/dn = 0 on [1,10,20]\n');
fprintf(' with \n');
fprintf('   a = %s \n',fc_tools.utils.fun2str(af));
fprintf('   b = %s \n',fc_tools.utils.fun2str(b));
fprintf('   gD = %s \n',fc_tools.utils.fun2str(gD));
fprintf('------------------------------------------------------\n');

fprintf('1. Building the mesh using GMSH\n');
meshfile=gmsh.buildmesh(geofile,N,'d',d,'geodir',geodir,'meshdir',meshdir);
Th=siMesh(meshfile);
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());

fprintf('2.a Setting 2D velocity potential BVP\n');
d=2;  
Hop=Hoperator(d,d,3);
Hop.set(1,2,Loperator(d,d,[],{-1,0},[],[]));
Hop.set(1,3,Loperator(d,d,[],{0,-1},[],[]));
Hop.set(2,1,Loperator(d,d,[],[],{-1,0},[]));
Hop.set(2,2,Loperator(d,d,[],[],[],1));
Hop.set(3,1,Loperator(d,d,[],[],{0,-1},[]));
Hop.set(3,3,Loperator(d,d,[],[],[],1));
bvpFlow=BVP(Th,PDEelt(Hop));
bvpFlow.setDirichlet(20,20,1);
bvpFlow.setDirichlet(21,-20,1);
fprintf('2.b Solving 2D potential velocity/flow BVP\n')
U=bvpFlow.solve('split',true); 

fprintf('3.a Setting 2D stationary heat BVP with potential flow\n');
Lop=Loperator(d,d,{af,[];[],af},[],{U{2},U{3}},b);
bvpHeat=BVP(Th,PDEelt(Lop));
bvpHeat.setDirichlet(21,gD);
bvpHeat.setDirichlet(22, 0);
bvpHeat.setDirichlet(23, 0);
fprintf('3.b Solving 2D stationary heat BVP with potential flow\n');
u=bvpHeat.solve();

fprintf('4. Graphic representations\n');
close all
options=fc_tools.graphics.DisplayFigures('nfig',6);
interpreter=@(x) fc_tools.graphics.interpreter(x);


figure(1)
Th.plotmesh('color',[0.9,0.9,0.9])
hold on
Th.plotmesh('d',1,'legend',true);
axis off,axis image
text(-0.5,0.5,interpreter('$\Omega$'),options.title{:},options.interpreter{:})
title(interpreter('2D stationary heat with potential flow - domain $\Omega$'),options.title{:},options.interpreter{:});

figure(2)
Th.plot(u)%,'PlotOptions',{'SpecularStrength',0.95})
colormap(jet)
hold on,axis off,axis image
%Th.plot(x,'PlotOptions',{'FaceAlpha',0.7,'FaceColor','interp','EdgeColor','none'})
%Th.plotiso(x,'niso',15,'PlotOptions',{'LineWidth',1});
Th.plotiso(u,'isorange',1:16,'Color','w')
axis off;axis image
shading interp
title('2D stationary heat with potential flow',options.title{:},options.interpreter{:})
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})

figure(3)
Th.plot(U{1})
hold on,axis off,axis image
Th.plotiso(U{1},'Color','w')
shading interp
colorbar(options.colorbar{:})
title(interpreter('Velocity potential $\phi$'),options.title{:})
set(get(colorbar(),'title'),'string',interpreter('$\phi$'),options.title{:},options.interpreter{:})

v2=sqrt(U{2}.^2+U{3}.^2);
figure(4)
Th.plot(v2)
hold on,axis off,axis image
Th.plotiso(v2,'niso',15,'Color','w')
shading interp,colorbar
title('Potential flow',options.title{:},options.interpreter{:})
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$\| \mathbf{V} \|_2$'),options.title{:},options.interpreter{:})

mv2=max(v2);
figure(5)
clf
colormap(jet)
Th.plotVectorField([U{2},U{3}]','colordata',u,'scale',3*Th.get_h()/mv2,'freq',3);
hold on,axis image, axis off
colorbar(options.colorbar{:})
Th.plotmesh('d',1,'color','k','Linewidth',2)
title(interpreter('Potential flow $\mathbf{V}$ colorized with heat $u$'),options.title{:},options.interpreter{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})

figure(6)
colormap(jet)
Th.plotVectorField([U{2},U{3}]','colordata',u,'scale',3*Th.get_h()/mv2,'freq',2);
hold on,axis image, axis off
colorbar(options.colorbar{:})
Th.plotmesh('d',1,'color','k','Linewidth',2)
axis([-1   -0.14   -0.45    0.4])
title(interpreter('Potential flow $\mathbf{V}$ colorized with heat $u$ (zoom)'),options.title{:},options.interpreter{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})

